@@ -1,6 +1,4 @@
-import os
 from datetime import datetime
-
 from fabric.api import *
 from fabric.colors import *
 from fabric.contrib.files import *
@@ -8,6 +6,7 @@ from fabric.contrib.console import confirm
 from fabric.operations import require
 from fabric.operations import open_shell
 from fabric.tasks import Task
+import os
 
 import deploytool.utils as utils
 
@@ -22,7 +21,7 @@ class RemoteHost(Task):
         'hosts',
         'project_name',
         'project_name_prefix',
-        'vhosts_path',
+        'projects_root',
     ]
 
     def __init__(self, *args, **kwargs):
@@ -41,22 +40,23 @@ class RemoteHost(Task):
         # check if all required project settings are present in fabric environment
         [require(r) for r in self.requirements]
 
-        vhost_folder = '%s%s' % (env.project_name_prefix, env.project_name)
-        vhost_path = os.path.join(env.vhosts_path, vhost_folder)
+        project_name = '%s%s' % (env.project_name_prefix, env.project_name)
+        project_path = os.path.join(env.projects_root, project_name)
 
         print(green('\nInitializing fabric environment for %s.' % magenta(self.name)))
         env.update({
-            'cache_path': os.path.join(vhost_path, 'cache'),
-            'current_instance_path': os.path.join(vhost_path, 'current_instance'),
-            'database_name': env.project_name,
+            'cache_path': os.path.join(project_path, 'cache'),
+            'current_instance_path': os.path.join(project_path, 'current_instance'),
+            'database_name': project_name,
             'environment': env.environment,
             'hosts': env.hosts,
-            'log_path': os.path.join(vhost_path, 'log'),
-            'media_path': os.path.join(vhost_path, 'media'),
-            'previous_instance_path': os.path.join(vhost_path, 'previous_instance'),
-            'vhost_path': vhost_path,
-            'scripts_path': os.path.join(vhost_path, 'scripts'),
-            'user': '%s%s' % (env.project_name_prefix, env.project_name),
+            'log_path': os.path.join(project_path, 'log'),
+            'media_path': os.path.join(project_path, 'media'),
+            'previous_instance_path': os.path.join(project_path, 'previous_instance'),
+            'project_root': env.projects_root,
+            'project_path': project_path,
+            'scripts_path': os.path.join(project_path, 'scripts'),
+            'user': project_name,
         })
 
 
@@ -68,7 +68,7 @@ class RemoteTask(Task):
     """
 
     requirements = [
-        'vhost_path',
+        'project_path',
         'project_name',
     ]
 
@@ -80,7 +80,7 @@ class RemoteTask(Task):
     def log(self, success):
         """ Single line task logging to ./log/fabric.log """
 
-        if success is True:
+        if success == True:
             result = 'success'
         else:
             result = 'failed'
@@ -119,14 +119,13 @@ class RemoteTask(Task):
             [require(r) for r in self.requirements]
 
             # update fabric environment for instance settings
-            instance_path = os.path.join(env.vhost_path, self.stamp)
+            instance_path = os.path.join(env.project_path, self.stamp)
             env.update({
                 'backup_path': os.path.join(instance_path, 'backup'),
                 'instance_stamp': self.stamp,
                 'instance_path': instance_path,
                 'source_path': os.path.join(instance_path, env.project_name),
-                'project_path': os.path.join(instance_path, env.project_name),
-                'project_project_path': os.path.join(instance_path, env.project_name, env.project_name),
+                'project_source_path': os.path.join(instance_path, env.project_name, getattr(env, 'project_source_folder', '')),
                 'virtualenv_path': os.path.join(instance_path, 'env'),
             })
 
@@ -141,13 +140,13 @@ class Deployment(RemoteTask):
         Usage:
 
         # default deployment using current git HEAD
-        $ fab staging deploy
+        $ fab staging.deploy
 
         # deployment for a specific git branch
-        $ fab staging deploy:branch=my-branch
+        $ fab staging.deploy:branch=my-branch
 
         # deployment for a specific git commit ID
-        $ fab staging deploy:commit=1ec9d293ce54647df7f15ee7c0295b8eb2a5cbef
+        $ fab staging.deploy:commit=1ec9d293ce54647df7f15ee7c0295b8eb2a5cbef
     """
 
     name = 'deploy'
@@ -164,11 +163,11 @@ class Deployment(RemoteTask):
         with settings(hide('warnings', 'running', 'stdout', 'stderr'), warn_only=True):
 
             # deploy by local commit
-            if 'commit' in kwargs:
+            if kwargs.has_key('commit'):
                 self.stamp = kwargs['commit']
 
             # deploy by HEAD for branch
-            elif 'branch' in kwargs:
+            elif kwargs.has_key('branch'):
                 self.stamp = utils.source.get_commit_id(kwargs['branch'])
 
             # deploy by local HEAD for local current branch
@@ -244,18 +243,17 @@ class Deployment(RemoteTask):
             if ('before_pip_install' in env):
                 env.before_pip_install(env, *args, **kwargs)
 
-            if exists(os.path.join(env.project_path, '*.pth')):
+            if exists(os.path.join(getattr(env, 'project_source_folder', '.'), '*.pth')):
                 print(green('\nCopying .pth files.'))
                 utils.commands.copy(
-                    from_path=os.path.join(env.project_path, '*.pth'),
+                    from_path=os.path.join(getattr(env, 'project_source_folder', '.'), '*.pth'),
                     to_path='%s/lib/python2.6/site-packages' % env.virtualenv_path
                 )
 
             print(green('\nPip installing requirements.'))
-            # TODO: use requirements_path instead of project_path?
             utils.instance.pip_install_requirements(
                 env.virtualenv_path,
-                env.project_path,
+                env.project_source_path,
                 env.cache_path,
                 env.log_path
             )
@@ -271,20 +269,20 @@ class Deployment(RemoteTask):
 
             print(green('\nCopying settings.py.'))
             utils.commands.copy(
-                from_path=os.path.join(env.vhost_path, 'settings.py'),
-                to_path=os.path.join(env.project_project_path, 'settings.py')
+                from_path = os.path.join(env.project_path, 'settings.py'),
+                to_path = os.path.join(env.project_source_path, 'settings.py')
             )
 
             print(green('\nLinking media folder.'))
             utils.commands.create_symbolic_link(
-                real_path=os.path.join(env.vhost_path, 'media'),
-                symbolic_path=os.path.join(env.project_path, 'media')
+                real_path = os.path.join(env.project_path, 'media'),
+                symbolic_path = os.path.join(env.project_source_path, 'media')
             )
 
             print(green('\nCollecting static files.'))
             utils.commands.django_manage(
                 env.virtualenv_path,
-                env.project_path,
+                env.project_source_path,
                 'collectstatic --link --noinput --verbosity=0 --traceback'
             )
         except:
@@ -316,7 +314,7 @@ class Deployment(RemoteTask):
                     env.before_syncdb(env, *args, **kwargs)
 
                 print(green('\nSyncing database.'))
-                utils.commands.django_manage(env.virtualenv_path, env.project_path, 'syncdb')
+                utils.commands.django_manage(env.virtualenv_path, env.project_source_path, 'syncdb')
                 print('')
 
                 # before_migrate pause
@@ -329,7 +327,7 @@ class Deployment(RemoteTask):
                     env.before_migrate(env, *args, **kwargs)
 
                 print(green('\nMigrating database.'))
-                utils.commands.django_manage(env.virtualenv_path, env.project_path, 'migrate')
+                utils.commands.django_manage(env.virtualenv_path, env.project_source_path, 'migrate')
                 print('')
 
             print(green('\nBacking up database at end.'))
@@ -363,10 +361,10 @@ class Deployment(RemoteTask):
             env.before_restart(env, *args, **kwargs)
 
         print(green('\nUpdating instance symlinks.'))
-        utils.instance.set_current_instance(env.vhost_path, env.instance_path)
+        utils.instance.set_current_instance(env.project_path, env.instance_path)
 
         print(green('\nRestarting website.'))
-        utils.commands.touch_wsgi(env.vhost_path)
+        utils.commands.touch_wsgi(env.project_path)
 
         # after_restart pause
         if ('after_restart' in pause_at):
@@ -383,14 +381,14 @@ class Deployment(RemoteTask):
     def prune_instances(self):
         """ Find old instances and remove them to free up space """
 
-        old_instances = utils.instance.get_obsolete_instances(env.vhost_path)
+        old_instances = utils.instance.get_obsolete_instances(env.project_path)
 
         for instance in old_instances:
             is_current = bool(utils.instance.get_instance_stamp(env.current_instance_path) == instance)
             is_previous = bool(utils.instance.get_instance_stamp(env.previous_instance_path) == instance)
 
             if not (is_current or is_previous):
-                utils.commands.delete(os.path.join(env.vhost_path, instance))
+                utils.commands.delete(os.path.join(env.project_path, instance))
 
         if len(old_instances) > 0:
             print(green('\nThese old instances were removed from remote filesystem:'))
@@ -420,10 +418,10 @@ class Rollback(RemoteTask):
             )
 
             print(green('\nRemoving this instance and set previous to current.'))
-            utils.instance.rollback(env.vhost_path)
+            utils.instance.rollback(env.project_path)
 
             print(green('\nRestarting website.'))
-            utils.commands.touch_wsgi(env.vhost_path)
+            utils.commands.touch_wsgi(env.project_path)
 
             print(green('\nRemoving this instance from filesystem.'))
             utils.commands.delete(env.instance_path)
@@ -485,12 +483,12 @@ class Media(RemoteTask):
         cwd = os.getcwd()
 
         print(green('\nCompressing remote media folder.'))
-        utils.commands.create_tarball(env.vhost_path, 'media', file_name)  # TODO: media_path?
+        utils.commands.create_tarball(env.project_path, 'media', file_name)
 
         print(green('\nDownloading tarball.'))
         utils.commands.download_file(
-            remote_path=os.path.join(env.vhost_path, file_name),
-            local_path=os.path.join(cwd, file_name)
+            remote_path = os.path.join(env.project_path, file_name),
+            local_path = os.path.join(cwd, file_name)
         )
 
         print(green('\nSaved media tarball to:'))
@@ -517,8 +515,8 @@ class Database(RemoteTask):
 
         print(green('\nDownloading and removing remote backup.'))
         utils.commands.download_file(
-            remote_path=os.path.join(env.backup_path, file_name),
-            local_path=os.path.join(os.getcwd(), file_name)
+            remote_path = os.path.join(env.backup_path, file_name),
+            local_path = os.path.join(os.getcwd(), file_name)
         )
 
         print(green('\nSaved backup to:'))
